# -*- coding: latin-1 -*-
###############################################################################
# Copyright © 2018 NetApp, Inc. All Rights Reserved.
#
# CONFIDENTIALITY NOTICE:  THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION OF
# NETAPP, INC. USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
# EXPRESS WRITTEN PERMISSION OF NETAPP, INC.
###############################################################################


from jose import jwt


def validate_access_token(token, certificate, audience, options=None):
    """
    Validate an access token signed by the authentication service
    :param token: The access token to validate
    :param certificate: The public certificate to use to validate the token
    :param audience: The audience to validate the token for
    :param options: Options to pass to jwt.decode to control what fields are validated.
    :return: A set of claims from the validated/decoded token
    """
    if not token:
        raise ValueError('Parameter token missing')

    if not certificate:
        raise ValueError("Parameter certificate missing")

    if not audience:
        raise ValueError("Parameter audience missing")

    return jwt.decode(token, certificate, algorithms="RS256", audience=audience, options=options)


